git

package
v0.20.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 11, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config added in v0.6.0

type Config struct {
	// MaxCommits limits the number of commits to index per repository.
	// Default: 500. Set to 0 for unlimited (not recommended for large repos).
	MaxCommits int
}

Config holds configuration for the git indexer.

type Indexer

type Indexer struct {
	// contains filtered or unexported fields
}

Indexer indexes git repositories.

func New

func New(cfg ...Config) *Indexer

New creates a new git indexer with optional configuration.

func (*Indexer) HandleEvent

func (i *Indexer) HandleEvent(ctx context.Context, ictx *indexer.Context, event indexer.Event) error

func (*Indexer) Handles

func (i *Indexer) Handles(uri string) bool

func (*Indexer) Index

func (i *Indexer) Index(ctx context.Context, ictx *indexer.Context) error

func (*Indexer) Name

func (i *Indexer) Name() string

func (*Indexer) Schemes

func (i *Indexer) Schemes() []string

func (*Indexer) Subscriptions

func (i *Indexer) Subscriptions() []indexer.Subscription

Directories

Path Synopsis
Package commitparser implements a lenient parser for Conventional Commits (https://www.conventionalcommits.org/).
Package commitparser implements a lenient parser for Conventional Commits (https://www.conventionalcommits.org/).

Jump to