Documentation
¶
Index ¶
- type Config
- type Indexer
- func (i *Indexer) HandleEvent(ctx context.Context, ictx *indexer.Context, event indexer.Event) error
- func (i *Indexer) Handles(uri string) bool
- func (i *Indexer) Index(ctx context.Context, ictx *indexer.Context) error
- func (i *Indexer) Name() string
- func (i *Indexer) Schemes() []string
- func (i *Indexer) Subscriptions() []indexer.Subscription
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶ added in v0.6.0
type Config struct {
// MaxCommits limits the number of commits to index per repository.
// Default: 500. Set to 0 for unlimited (not recommended for large repos).
MaxCommits int
}
Config holds configuration for the git indexer.
type Indexer ¶
type Indexer struct {
// contains filtered or unexported fields
}
Indexer indexes git repositories.
func (*Indexer) HandleEvent ¶
func (*Indexer) Subscriptions ¶
func (i *Indexer) Subscriptions() []indexer.Subscription
Directories
¶
| Path | Synopsis |
|---|---|
|
Package commitparser implements a lenient parser for Conventional Commits (https://www.conventionalcommits.org/).
|
Package commitparser implements a lenient parser for Conventional Commits (https://www.conventionalcommits.org/). |
Click to show internal directories.
Click to hide internal directories.